# Generated by Django 3.2.13 on 2022-09-09 23:21

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("calaccess_raw", "0025_auto_20220725_1711"),
    ]

    operations = [
        migrations.DeleteModel(
            name="RawDataFile",
        ),
        migrations.DeleteModel(
            name="RawDataVersion",
        ),
    ]
