# Generated by Django 4.0.8 on 2022-10-31 14:44

import calaccess_raw.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('calaccess_raw', '0026_auto_20220909_2321'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cvre530cd',
            name='other_desc',
            field=calaccess_raw.fields.CharField(db_column='OTHER_DESC', help_text='This field is undocumented', max_length=500),
        ),
    ]
