# Generated by Django 4.1.13 on 2024-07-12 12:55

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("calaccess_raw", "0027_alter_cvre530cd_other_desc"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="cvrf470cd",
            name="cand_adr1",
        ),
    ]
