# -*- coding: utf-8 -*-
# Generated by Django 1.10 on 2016-10-28 01:29
from __future__ import unicode_literals

import calaccess_raw.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("calaccess_raw", "0010_auto_20161026_1643"),
    ]

    operations = [
        migrations.AlterField(
            model_name="expncd",
            name="bakref_tid",
            field=calaccess_raw.fields.CharField(
                blank=True,
                db_column="BAKREF_TID",
                help_text="Back Reference to a Tran_ID of a 'parent' record",
                max_length=20,
                verbose_name="back reference transaction id",
            ),
        ),
        migrations.AlterField(
            model_name="expncd",
            name="bal_juris",
            field=calaccess_raw.fields.CharField(
                blank=True,
                db_column="BAL_JURIS",
                help_text="Ballot measure's jurisdiction",
                max_length=40,
                verbose_name="ballot measure jurisdiction",
            ),
        ),
        migrations.AlterField(
            model_name="expncd",
            name="bal_name",
            field=calaccess_raw.fields.CharField(
                blank=True,
                db_column="BAL_NAME",
                help_text="Ballot Measure Name",
                max_length=200,
                verbose_name="ballot measure name",
            ),
        ),
        migrations.AlterField(
            model_name="expncd",
            name="bal_num",
            field=calaccess_raw.fields.CharField(
                blank=True,
                db_column="BAL_NUM",
                help_text="Ballot Number or Letter",
                max_length=7,
                verbose_name="ballot measure number",
            ),
        ),
        migrations.AlterField(
            model_name="expncd",
            name="expn_dscr",
            field=calaccess_raw.fields.CharField(
                blank=True,
                db_column="EXPN_DSCR",
                help_text="Purpose of expense and/or description/explanation",
                max_length=400,
                verbose_name="expense description",
            ),
        ),
    ]
